@@ -3,7 +3,7 @@ tablet.py – Flatland binds a Canvas instance in the Flatland Application domai
 in the drawing domain. The Tablet can be drawn using cairo or some other graphics drawing framework.
 """
 import logging
-from flatland.flatland_exceptions import NonSystemInitialLayer
+from flatland.flatland_exceptions import NonSystemInitialLayer, TabletBoundsExceeded
 from flatland.datatypes.geometry_types import Rect_Size, Position
 import cairo
 from flatland.drawing_domain.styledb import StyleDB
@@ -84,12 +84,13 @@ class Tablet:
         self.PDF_sheet = cairo.PDFSurface(self.Output_file, self.Size.width, self.Size.height)
         self.Context = cairo.Context(self.PDF_sheet)
 
-    def add_layer(self, name: str, presentation: str, drawing_type: str) -> Optional[Layer]:
+    def add_layer(self, name: str, presentation: str, drawing_type: str, fill: str = None) -> Optional[Layer]:
         """Add a new layer if not already instantiated and return it"""
         if not self.layers.get(name):
             if name not in self.layer_order:
                 self.layer_order.append(name)
-            self.layers[name] = Layer(name=name, tablet=self, presentation=presentation, drawing_type=drawing_type)
+            self.layers[name] = Layer(name=name, tablet=self, presentation=presentation, drawing_type=drawing_type,
+                                      fill=fill)
             return self.layers[name]
         else:
             self.logger.warning(f"Layer: [{name}] previously instantiated")
@@ -106,7 +107,8 @@ class Tablet:
         To display coordinates – Convert tablet bottom_left origin coordinate to
         display coordinate where top-left origin is used.
         """
-        assert tablet_coord.y <= self.Size.height, "Tablet bounds exceeded"
+        if tablet_coord.y > self.Size.height:
+            raise TabletBoundsExceeded
         assert tablet_coord.x >= 0, "Negative x value"
         assert tablet_coord.y >= 0, "Negative y value"
         return Position(x=tablet_coord.x, y=self.Size.height - tablet_coord.y)
